@@ -14,7 +14,7 @@ import os
 import mock
 from pprint import pformat
 import warnings
-from nose.tools import assert_equals, assert_true
+from nose.tools import assert_equal, assert_true
 
 from botocore import xform_name
 import botocore.session
@@ -30,6 +30,10 @@ from botocore.vendored.requests.exceptions import ConnectionError
 SMOKE_TESTS = {
  'acm': {'ListCertificates': {}},
  'apigateway': {'GetRestApis': {}},
+ 'application-autoscaling': {
+     'DescribeScalableTargets': {
+         'ServiceNamespace': 'ecs'
+     }},
  'autoscaling': {'DescribeAccountLimits': {},
                  'DescribeAdjustmentTypes': {}},
  'cloudformation': {'DescribeStacks': {},
@@ -44,8 +48,6 @@ SMOKE_TESTS = {
  'codecommit': {'ListRepositories': {}},
  'codedeploy': {'ListApplications': {}},
  'codepipeline': {'ListActionTypes': {}},
- 'codedeploy': {'ListApplications': {}},
- 'codecommit': {'ListRepositories': {}},
  'cognito-identity': {'ListIdentityPools': {'MaxResults': 1}},
  'cognito-sync': {'ListIdentityPoolUsage': {}},
  'config': {'DescribeDeliveryChannels': {}},
@@ -111,6 +113,10 @@ SMOKE_TESTS = {
 # we've sent invalid params.
 ERROR_TESTS = {
     'apigateway': {'GetRestApi': {'restApiId': 'fake-id'}},
+    'application-autoscaling': {
+        'DescribeScalableTargets': {
+            'ServiceNamespace': 'fake-service-namespace'
+        }},
     'autoscaling': {'CreateLaunchConfiguration': {
         'LaunchConfigurationName': 'foo',
         'ImageId': 'ami-12345678',
@@ -240,9 +246,9 @@ def _make_client_call(client, operation_name, kwargs):
     method = getattr(client, operation_name)
     with warnings.catch_warnings(record=True) as caught_warnings:
         response = method(**kwargs)
-        assert_equals(len(caught_warnings), 0,
-                      "Warnings were emitted during smoke test: %s"
-                      % caught_warnings)
+        assert_equal(len(caught_warnings), 0,
+                     "Warnings were emitted during smoke test: %s"
+                     % caught_warnings)
         assert_true('Errors' not in response)
 
 
